#ifndef NT2_INCLUDE_CONSTANTS_NBDIGITS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_NBDIGITS_HPP_INCLUDED

#include <nt2/constant/include/constants/nbdigits.hpp>

#endif
